Index: src/mips/full-codegen-mips.cc |
diff --git a/src/mips/full-codegen-mips.cc b/src/mips/full-codegen-mips.cc |
index 103ab4144d3474f3e4cccc9510eaf81e3e823264..93c75c38fe7e8410d9e71ae0f26ec55d2d648267 100644 |
--- a/src/mips/full-codegen-mips.cc |
+++ b/src/mips/full-codegen-mips.cc |
@@ -1322,9 +1322,9 @@ void FullCodeGenerator::EmitLoadGlobalCheckExtensions(Variable* var, |
__ Move(next, current); |
} |
__ bind(&loop); |
// Terminate at global context. |
__ lw(temp, FieldMemOperand(next, HeapObject::kMapOffset)); |
- __ LoadRoot(t0, Heap::kGlobalContextMapRootIndex); |
+ __ LoadRoot(t0, Heap::kNativeContextMapRootIndex); |
__ Branch(&fast, eq, temp, Operand(t0)); |
// Check that extension is NULL. |
__ lw(temp, ContextOperand(next, Context::EXTENSION_INDEX)); |
@@ -2789,7 +2789,7 @@ void FullCodeGenerator::EmitIsStringWrapperSafeForDefaultValueOf( |
__ JumpIfSmi(a2, if_false); |
__ lw(a2, FieldMemOperand(a2, HeapObject::kMapOffset)); |
__ lw(a3, ContextOperand(cp, Context::GLOBAL_INDEX)); |
- __ lw(a3, FieldMemOperand(a3, GlobalObject::kGlobalContextOffset)); |
+ __ lw(a3, FieldMemOperand(a3, GlobalObject::kNativeContextOffset)); |
__ lw(a3, ContextOperand(a3, Context::STRING_FUNCTION_PROTOTYPE_MAP_INDEX)); |
__ Branch(if_false, ne, a2, Operand(a3)); |
@@ -3070,7 +3070,7 @@ void FullCodeGenerator::EmitRandomHeapNumber(CallRuntime* expr) { |
if (CpuFeatures::IsSupported(FPU)) { |
__ PrepareCallCFunction(1, a0); |
__ lw(a0, ContextOperand(cp, Context::GLOBAL_INDEX)); |
- __ lw(a0, FieldMemOperand(a0, GlobalObject::kGlobalContextOffset)); |
+ __ lw(a0, FieldMemOperand(a0, GlobalObject::kNativeContextOffset)); |
__ CallCFunction(ExternalReference::random_uint32_function(isolate()), 1); |
CpuFeatures::Scope scope(FPU); |
@@ -3088,7 +3088,7 @@ void FullCodeGenerator::EmitRandomHeapNumber(CallRuntime* expr) { |
__ PrepareCallCFunction(2, a0); |
__ mov(a0, s0); |
__ lw(a1, ContextOperand(cp, Context::GLOBAL_INDEX)); |
- __ lw(a1, FieldMemOperand(a1, GlobalObject::kGlobalContextOffset)); |
+ __ lw(a1, FieldMemOperand(a1, GlobalObject::kNativeContextOffset)); |
__ CallCFunction( |
ExternalReference::fill_heap_number_with_random_function(isolate()), 2); |
} |
@@ -3503,7 +3503,7 @@ void FullCodeGenerator::EmitGetFromCache(CallRuntime* expr) { |
int cache_id = Smi::cast(*(args->at(0)->AsLiteral()->handle()))->value(); |
Handle<FixedArray> jsfunction_result_caches( |
- isolate()->global_context()->jsfunction_result_caches()); |
+ isolate()->native_context()->jsfunction_result_caches()); |
if (jsfunction_result_caches->length() <= cache_id) { |
__ Abort("Attempt to use undefined cache."); |
__ LoadRoot(v0, Heap::kUndefinedValueRootIndex); |
@@ -3516,7 +3516,7 @@ void FullCodeGenerator::EmitGetFromCache(CallRuntime* expr) { |
Register key = v0; |
Register cache = a1; |
__ lw(cache, ContextOperand(cp, Context::GLOBAL_INDEX)); |
- __ lw(cache, FieldMemOperand(cache, GlobalObject::kGlobalContextOffset)); |
+ __ lw(cache, FieldMemOperand(cache, GlobalObject::kNativeContextOffset)); |
__ lw(cache, |
ContextOperand( |
cache, Context::JSFUNCTION_RESULT_CACHES_INDEX)); |
@@ -4495,7 +4495,7 @@ void FullCodeGenerator::PushFunctionArgumentForContextAllocation() { |
Scope* declaration_scope = scope()->DeclarationScope(); |
if (declaration_scope->is_global_scope() || |
declaration_scope->is_module_scope()) { |
// Contexts nested in the global context have a canonical empty function |
// as their closure, not the anonymous closure containing the global |
// code. Pass a smi sentinel and let the runtime look up the empty |
// function. |
@@ -1322,9 +1322,9 @@ void FullCodeGenerator::EmitLoadGlobalCheckExtensions(Variable* var, |
} |
__ bind(&loop); |
- // Terminate at global context. |
+ // Terminate at native context. |
__ lw(temp, FieldMemOperand(next, HeapObject::kMapOffset)); |
@@ -4495,7 +4495,7 @@ void FullCodeGenerator::PushFunctionArgumentForContextAllocation() { |
if (declaration_scope->is_global_scope() || |
declaration_scope->is_module_scope()) { |
- // Contexts nested in the global context have a canonical empty function |
+ // Contexts nested in the native context have a canonical empty function |
// as their closure, not the anonymous closure containing the global |
// code. Pass a smi sentinel and let the runtime look up the empty |